#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error meh!
#endif

GO(xcb_shape_combine, pFbuuupwwp)
GO(xcb_shape_combine_checked, pFbuuupwwp)
GO(xcb_shape_get_rectangles, pFbpi)
GO(xcb_shape_get_rectangles_rectangles, pFp)
//GO(xcb_shape_get_rectangles_rectangles_iterator, 
GO(xcb_shape_get_rectangles_rectangles_length, iFp)
GO(xcb_shape_get_rectangles_reply, pFbup)
//GO(xcb_shape_get_rectangles_sizeof, 
//GO(xcb_shape_get_rectangles_unchecked, 
DATA(xcb_shape_id, 8)
//GO(xcb_shape_input_selected, 
//GO(xcb_shape_input_selected_reply, 
//GO(xcb_shape_input_selected_unchecked, 
//GO(xcb_shape_kind_end, 
//GO(xcb_shape_kind_next, 
GO(xcb_shape_mask, uFbuuuwwu)
GO(xcb_shape_mask_checked, uFbuuuwwu)
//GO(xcb_shape_offset, 
//GO(xcb_shape_offset_checked, 
//GO(xcb_shape_op_end, 
//GO(xcb_shape_op_next, 
//GO(xcb_shape_query_extents, 
//GO(xcb_shape_query_extents_reply, 
//GO(xcb_shape_query_extents_unchecked, 
GO(xcb_shape_query_version, uFb)
GO(xcb_shape_query_version_reply, pFbup)
GO(xcb_shape_query_version_unchecked, uFb)
GO(xcb_shape_rectangles, pFbiiCpWWup)
//GO(xcb_shape_rectangles_checked, 
//GO(xcb_shape_rectangles_rectangles, 
//GO(xcb_shape_rectangles_rectangles_iterator, 
//GO(xcb_shape_rectangles_rectangles_length, 
//GO(xcb_shape_rectangles_sizeof, 
//GO(xcb_shape_select_input, 
//GO(xcb_shape_select_input_checked, 
